# PDB

Get structure and metadata of a protein from the [RCSB Protein Data Bank](https://rcsb.org)

There are currently two submodules in PDB:

| Module | Description |
|--------|-------------|
|[`structure`](./pdb/structure.md)| Retrieves PDB structure for a provided RCSB ID |
|[`info`](./pdb/info.md)| Retrieves Protein information for a provided RCSB ID |

